diff -u asterisk-11.15.0/configure.ac asterisk-11.15.0-address/configure.ac
--- asterisk-11.15.0/configure.ac	2014-08-18 02:32:25.000000000 +0400
+++ asterisk-11.15.0-address/configure.ac	2015-01-23 18:31:52.141948972 +0300
@@ -335,6 +335,17 @@
 
 AC_LANG(C)
 
+
+AC_ARG_ENABLE([sanitize],
+	[AS_HELP_STRING([--enable-sanitize=Value],
+		[Enables the specified compiler sanitizer. VALUE=address|thread|leak|undefined])],
+	[case "${enableval}" in
+	      address|thread|leak|undefined) AST_SANITIZE="${enableval}"
+	      ;;
+	      *) AC_MSG_ERROR(bad value ${enableval} for --enable-sanitize)  ;;
+	esac])
+AC_SUBST(AST_SANITIZE)
+
 AC_ARG_ENABLE([dev-mode],
 	[AS_HELP_STRING([--enable-dev-mode],
 		[Turn on developer mode])],
diff -u asterisk-11.15.0/Makefile.rules asterisk-11.15.0-address/Makefile.rules
--- asterisk-11.15.0/Makefile.rules	2014-11-12 16:44:32.000000000 +0300
+++ asterisk-11.15.0-address/Makefile.rules	2015-01-23 18:44:22.557997565 +0300
@@ -27,6 +27,28 @@
 # extra cflags to build dependencies. Recursively expanded.
 MAKE_DEPS=-MD -MT $@ -MF .$(subst /,_,$@).d -MP
 
+
+ifeq ($(AST_SANITIZE),address)
+	_ASTLDFLAGS+=-fsanitize=${AST_SANITIZE}
+	_ASTCFLAGS+=-fno-omit-frame-pointer -fsanitize=${AST_SANITIZE}
+	_ASTCXXFLAGS+=-fno-omit-frame-pointer -fsanitize=${AST_SANITIZE}
+endif
+ifeq ($(AST_SANITIZE),leak)
+	_ASTLDFLAGS+=-fsanitize=${AST_SANITIZE}
+	_ASTCFLAGS+=-fno-omit-frame-pointer -fsanitize=${AST_SANITIZE}
+	_ASTCXXFLAGS+=-fno-omit-frame-pointer -fsanitize=${AST_SANITIZE}
+endif
+ifeq ($(AST_SANITIZE),thread)
+	_ASTLDFLAGS+=-fsanitize=${AST_SANITIZE} -fPIE -pie
+	_ASTCFLAGS+=-fno-omit-frame-pointer -fPIE -pie -fsanitize=${AST_SANITIZE}
+	_ASTCXXFLAGS+=-fno-omit-frame-pointer -fPIE -pie -fsanitize=${AST_SANITIZE}
+endif
+ifeq ($(AST_SANITIZE),undefined)
+	_ASTLDFLAGS+=-fsanitize=${AST_SANITIZE}
+	_ASTCFLAGS+=-fno-omit-frame-pointer -fsanitize=${AST_SANITIZE}
+	_ASTCXXFLAGS+=-fno-omit-frame-pointer -fsanitize=${AST_SANITIZE}
+endif
+ 
 ifeq ($(NOISY_BUILD),)
     ECHO_PREFIX=@
     CMD_PREFIX=@
diff -u asterisk-11.15.0/makeopts.in asterisk-11.15.0-address/makeopts.in
--- asterisk-11.15.0/makeopts.in	2013-04-11 23:59:35.000000000 +0400
+++ asterisk-11.15.0-address/makeopts.in	2015-01-23 18:39:18.586646952 +0300
@@ -95,6 +95,7 @@
 ASTVARRUNDIR = @astvarrundir@
 
 AST_DEVMODE=@AST_DEVMODE@
+AST_SANITIZE=@AST_SANITIZE@
 AST_DEVMODE_STRICT=@AST_DEVMODE_STRICT@
 NOISY_BUILD=@NOISY_BUILD@
 
